@@ -1,4 +1,4 @@
-package OpenStack::MetaAPI::API::Specs::Compute::v2_1;
+package OpenStack::MetaAPI::API::Specs::Compute::v2_0;
 
 use strict;
 use warnings;
@@ -21,11 +21,11 @@ with 'OpenStack::MetaAPI::API::Specs::Roles::Service';
 
 =head1 NAME
 
-OpenStack::MetaAPI::API::Specs::Compute::v2_1
+OpenStack::MetaAPI::API::Specs::Compute::v2_0
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 AUTHOR
 
@@ -47,7 +47,6 @@ get:
     perl_api:
       method: server_from_uid
       type: getfromid
-      uid: '{server_id}'
     request:
       path:
         server_id:
@@ -64,20 +63,6 @@ get:
         hostname: {}
         image: {}
         ip: {}
-  /flavors:
-    perl_api:
-      method: flavors
-      type: listable
-      listable_key: 'flavors'
-    request:
-      query:
-        sort_key: {}
-        sort_dir: {}
-        limit: {}
-        marker: {}
-        minDisk: {}
-        minRam: {}
-        isPublic: {}
   /os-keypairs:
     perl_api:
       method: keypairs
@@ -93,7 +78,6 @@ delete:
     perl_api:
       method: delete_server_from_uid
       type: getfromid
-      uid: '{server_id}'
     request:
       path:
         server_id:
